# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKQuadEdgeMeshPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkQuadEdgeMeshLineCellPython
else:
    import _itkQuadEdgeMeshLineCellPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkArrayPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkGeometricalQuadEdgePython
import itk.itkQuadEdgePython
import itk.itkQuadEdgeCellTraitsInfoPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkQuadEdgeMeshPointPython
class itkCellInterfaceDQEMCTI2(object):
    r"""Proxy of C++ itkCellInterfaceDQEMCTI2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def Accept(self, cellId, arg1):
        r"""
        Accept(self, cellId, arg1)

        Parameters
        ----------
        cellId: unsigned long
        arg1: itkCellInterfaceDQEMCTI2::MultiVisitor *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_Accept(self, cellId, arg1)

    def GetType(self):
        r"""GetType(self) -> itkCommonEnums::CellGeometry"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_GetType(self)

    def MakeCopy(self, arg0):
        r"""
        MakeCopy(self, arg0)

        Parameters
        ----------
        arg0: itkCellInterfaceDQEMCTI2_AutoPointer &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_MakeCopy(self, arg0)

    def GetDimension(self):
        r"""GetDimension(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_GetDimension(self)

    def GetInterpolationOrder(self):
        r"""GetInterpolationOrder(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_GetInterpolationOrder(self)

    def GetNumberOfPoints(self):
        r"""GetNumberOfPoints(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_GetNumberOfPoints(self)

    def GetNumberOfBoundaryFeatures(self, dimension):
        r"""
        GetNumberOfBoundaryFeatures(self, dimension) -> unsigned char

        Parameters
        ----------
        dimension: int

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_GetNumberOfBoundaryFeatures(self, dimension)

    def GetBoundaryFeature(self, dimension, arg1, arg2):
        r"""
        GetBoundaryFeature(self, dimension, arg1, arg2) -> bool

        Parameters
        ----------
        dimension: int
        arg1: unsigned char
        arg2: itkCellInterfaceDQEMCTI2_AutoPointer &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_GetBoundaryFeature(self, dimension, arg1, arg2)

    def GetPointIds(self):
        r"""GetPointIds(self) -> unsigned long const *"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_GetPointIds(self)

    def SetPointIds(self, *args):
        r"""
        SetPointIds(self, first)

        Parameters
        ----------
        first: unsigned long const *

        SetPointIds(self, first, last)

        Parameters
        ----------
        first: unsigned long const *
        last: unsigned long const *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_SetPointIds(self, *args)

    def SetPointId(self, localId, arg1):
        r"""
        SetPointId(self, localId, arg1)

        Parameters
        ----------
        localId: int
        arg1: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_SetPointId(self, localId, arg1)

    def PointIdsBegin(self, *args):
        r"""
        PointIdsBegin(self) -> unsigned long
        PointIdsBegin(self) -> unsigned long const *
        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_PointIdsBegin(self, *args)

    def PointIdsEnd(self, *args):
        r"""
        PointIdsEnd(self) -> unsigned long
        PointIdsEnd(self) -> unsigned long const *
        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_PointIdsEnd(self, *args)

    def GetPointIdsContainer(self):
        r"""GetPointIdsContainer(self) -> itkArrayUL"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_GetPointIdsContainer(self)

    def SetPointIdsContainer(self, arg0):
        r"""
        SetPointIdsContainer(self, arg0)

        Parameters
        ----------
        arg0: itkArrayUL const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_SetPointIdsContainer(self, arg0)

    def GetClosestBoundary(self, arg0, arg1, arg2):
        r"""
        GetClosestBoundary(self, arg0, arg1, arg2) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: bool *
        arg2: itkCellInterfaceDQEMCTI2_AutoPointer &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_GetClosestBoundary(self, arg0, arg1, arg2)

    def EvaluatePosition(self, arg0, arg1, arg2, arg3, arg4, arg5):
        r"""
        EvaluatePosition(self, arg0, arg1, arg2, arg3, arg4, arg5) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: itkMapContainerULQEMPF2GQEULULBBT *
        arg2: float *
        arg3: float *
        arg4: double *
        arg5: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_EvaluatePosition(self, arg0, arg1, arg2, arg3, arg4, arg5)

    def EvaluateShapeFunctions(self, arg0, arg1):
        r"""
        EvaluateShapeFunctions(self, arg0, arg1)

        Parameters
        ----------
        arg0: itkArrayF const &
        arg1: itkArrayF &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_EvaluateShapeFunctions(self, arg0, arg1)

    def IntersectWithLine(self, arg0, arg1, arg2, arg3, arg4, arg5):
        r"""
        IntersectWithLine(self, arg0, arg1, arg2, arg3, arg4, arg5) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: float *
        arg2: float
        arg3: float *
        arg4: float *
        arg5: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_IntersectWithLine(self, arg0, arg1, arg2, arg3, arg4, arg5)

    def GetBoundingBox(self, arg0):
        r"""
        GetBoundingBox(self, arg0) -> float *

        Parameters
        ----------
        arg0: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_GetBoundingBox(self, arg0)

    def GetBoundingBoxDiagonalLength2(self):
        r"""GetBoundingBoxDiagonalLength2(self) -> float"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_GetBoundingBoxDiagonalLength2(self)

    def IntersectBoundingBoxWithLine(self, arg0, arg1, arg2, arg3, arg4):
        r"""
        IntersectBoundingBoxWithLine(self, arg0, arg1, arg2, arg3, arg4) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: float *
        arg2: float *
        arg3: float *
        arg4: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_IntersectBoundingBoxWithLine(self, arg0, arg1, arg2, arg3, arg4)

    def IsExplicitBoundary(self):
        r"""IsExplicitBoundary(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_IsExplicitBoundary(self)

    def AddUsingCell(self, cellId):
        r"""
        AddUsingCell(self, cellId)

        Parameters
        ----------
        cellId: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AddUsingCell(self, cellId)

    def RemoveUsingCell(self, cellId):
        r"""
        RemoveUsingCell(self, cellId)

        Parameters
        ----------
        cellId: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_RemoveUsingCell(self, cellId)

    def IsUsingCell(self, cellId):
        r"""
        IsUsingCell(self, cellId) -> bool

        Parameters
        ----------
        cellId: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_IsUsingCell(self, cellId)

    def GetNumberOfUsingCells(self):
        r"""GetNumberOfUsingCells(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_GetNumberOfUsingCells(self)

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_GetNameOfClass(self)
    __swig_destroy__ = _itkQuadEdgeMeshLineCellPython.delete_itkCellInterfaceDQEMCTI2

# Register itkCellInterfaceDQEMCTI2 in _itkQuadEdgeMeshLineCellPython:
_itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_swigregister(itkCellInterfaceDQEMCTI2)
class itkCellInterfaceDQEMCTI2_AutoPointer(object):
    r"""Proxy of C++ itkCellInterfaceDQEMCTI2_AutoPointer class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(self) -> itkCellInterfaceDQEMCTI2_AutoPointer
        __init__(self, p) -> itkCellInterfaceDQEMCTI2_AutoPointer

        Parameters
        ----------
        p: itkCellInterfaceDQEMCTI2_AutoPointer &

        __init__(self, p, takeOwnership) -> itkCellInterfaceDQEMCTI2_AutoPointer

        Parameters
        ----------
        p: itkCellInterfaceDQEMCTI2 *
        takeOwnership: bool

        """
        _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_swiginit(self, _itkQuadEdgeMeshLineCellPython.new_itkCellInterfaceDQEMCTI2_AutoPointer(*args))
    __swig_destroy__ = _itkQuadEdgeMeshLineCellPython.delete_itkCellInterfaceDQEMCTI2_AutoPointer

    def __deref__(self):
        r"""__deref__(self) -> itkCellInterfaceDQEMCTI2"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer___deref__(self)

    def Reset(self):
        r"""Reset(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_Reset(self)

    def TakeOwnership(self, *args):
        r"""
        TakeOwnership(self)
        TakeOwnership(self, objectptr)

        Parameters
        ----------
        objectptr: itkCellInterfaceDQEMCTI2 *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_TakeOwnership(self, *args)

    def TakeNoOwnership(self, objectptr):
        r"""
        TakeNoOwnership(self, objectptr)

        Parameters
        ----------
        objectptr: itkCellInterfaceDQEMCTI2 *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_TakeNoOwnership(self, objectptr)

    def IsOwner(self):
        r"""IsOwner(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_IsOwner(self)

    def ReleaseOwnership(self):
        r"""ReleaseOwnership(self) -> itkCellInterfaceDQEMCTI2"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_ReleaseOwnership(self)

    def GetPointer(self):
        r"""GetPointer(self) -> itkCellInterfaceDQEMCTI2"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_GetPointer(self)

    def __eq__(self, r):
        r"""
        __eq__(self, r) -> bool

        Parameters
        ----------
        r: itkCellInterfaceDQEMCTI2_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer___eq__(self, r)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkCellInterfaceDQEMCTI2_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer___ne__(self, other)

    def __lt__(self, r):
        r"""
        __lt__(self, r) -> bool

        Parameters
        ----------
        r: itkCellInterfaceDQEMCTI2_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer___lt__(self, r)

    def __gt__(self, r):
        r"""
        __gt__(self, r) -> bool

        Parameters
        ----------
        r: itkCellInterfaceDQEMCTI2_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer___gt__(self, r)

    def __le__(self, r):
        r"""
        __le__(self, r) -> bool

        Parameters
        ----------
        r: itkCellInterfaceDQEMCTI2_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer___le__(self, r)

    def __ge__(self, r):
        r"""
        __ge__(self, r) -> bool

        Parameters
        ----------
        r: itkCellInterfaceDQEMCTI2_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer___ge__(self, r)

    def Accept(self, cellId, arg1):
        r"""
        Accept(self, cellId, arg1)

        Parameters
        ----------
        cellId: unsigned long
        arg1: itkCellInterfaceDQEMCTI2::MultiVisitor *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_Accept(self, cellId, arg1)

    def GetType(self):
        r"""GetType(self) -> itkCommonEnums::CellGeometry"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_GetType(self)

    def MakeCopy(self, arg0):
        r"""
        MakeCopy(self, arg0)

        Parameters
        ----------
        arg0: itkCellInterfaceDQEMCTI2_AutoPointer &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_MakeCopy(self, arg0)

    def GetDimension(self):
        r"""GetDimension(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_GetDimension(self)

    def GetInterpolationOrder(self):
        r"""GetInterpolationOrder(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_GetInterpolationOrder(self)

    def GetNumberOfPoints(self):
        r"""GetNumberOfPoints(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_GetNumberOfPoints(self)

    def GetNumberOfBoundaryFeatures(self, dimension):
        r"""
        GetNumberOfBoundaryFeatures(self, dimension) -> unsigned char

        Parameters
        ----------
        dimension: int

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_GetNumberOfBoundaryFeatures(self, dimension)

    def GetBoundaryFeature(self, dimension, arg1, arg2):
        r"""
        GetBoundaryFeature(self, dimension, arg1, arg2) -> bool

        Parameters
        ----------
        dimension: int
        arg1: unsigned char
        arg2: itkCellInterfaceDQEMCTI2_AutoPointer &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_GetBoundaryFeature(self, dimension, arg1, arg2)

    def GetPointIds(self):
        r"""GetPointIds(self) -> unsigned long const *"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_GetPointIds(self)

    def SetPointIds(self, *args):
        r"""
        SetPointIds(self, first)

        Parameters
        ----------
        first: unsigned long const *

        SetPointIds(self, first, last)

        Parameters
        ----------
        first: unsigned long const *
        last: unsigned long const *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_SetPointIds(self, *args)

    def SetPointId(self, localId, arg1):
        r"""
        SetPointId(self, localId, arg1)

        Parameters
        ----------
        localId: int
        arg1: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_SetPointId(self, localId, arg1)

    def PointIdsBegin(self, *args):
        r"""
        PointIdsBegin(self) -> unsigned long
        PointIdsBegin(self) -> unsigned long const *
        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_PointIdsBegin(self, *args)

    def PointIdsEnd(self, *args):
        r"""
        PointIdsEnd(self) -> unsigned long
        PointIdsEnd(self) -> unsigned long const *
        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_PointIdsEnd(self, *args)

    def GetPointIdsContainer(self):
        r"""GetPointIdsContainer(self) -> itkArrayUL"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_GetPointIdsContainer(self)

    def SetPointIdsContainer(self, arg0):
        r"""
        SetPointIdsContainer(self, arg0)

        Parameters
        ----------
        arg0: itkArrayUL const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_SetPointIdsContainer(self, arg0)

    def GetClosestBoundary(self, arg0, arg1, arg2):
        r"""
        GetClosestBoundary(self, arg0, arg1, arg2) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: bool *
        arg2: itkCellInterfaceDQEMCTI2_AutoPointer &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_GetClosestBoundary(self, arg0, arg1, arg2)

    def EvaluatePosition(self, arg0, arg1, arg2, arg3, arg4, arg5):
        r"""
        EvaluatePosition(self, arg0, arg1, arg2, arg3, arg4, arg5) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: itkMapContainerULQEMPF2GQEULULBBT *
        arg2: float *
        arg3: float *
        arg4: double *
        arg5: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_EvaluatePosition(self, arg0, arg1, arg2, arg3, arg4, arg5)

    def EvaluateShapeFunctions(self, arg0, arg1):
        r"""
        EvaluateShapeFunctions(self, arg0, arg1)

        Parameters
        ----------
        arg0: itkArrayF const &
        arg1: itkArrayF &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_EvaluateShapeFunctions(self, arg0, arg1)

    def IntersectWithLine(self, arg0, arg1, arg2, arg3, arg4, arg5):
        r"""
        IntersectWithLine(self, arg0, arg1, arg2, arg3, arg4, arg5) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: float *
        arg2: float
        arg3: float *
        arg4: float *
        arg5: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_IntersectWithLine(self, arg0, arg1, arg2, arg3, arg4, arg5)

    def GetBoundingBox(self, arg0):
        r"""
        GetBoundingBox(self, arg0) -> float *

        Parameters
        ----------
        arg0: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_GetBoundingBox(self, arg0)

    def GetBoundingBoxDiagonalLength2(self):
        r"""GetBoundingBoxDiagonalLength2(self) -> float"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_GetBoundingBoxDiagonalLength2(self)

    def IntersectBoundingBoxWithLine(self, arg0, arg1, arg2, arg3, arg4):
        r"""
        IntersectBoundingBoxWithLine(self, arg0, arg1, arg2, arg3, arg4) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: float *
        arg2: float *
        arg3: float *
        arg4: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_IntersectBoundingBoxWithLine(self, arg0, arg1, arg2, arg3, arg4)

    def IsExplicitBoundary(self):
        r"""IsExplicitBoundary(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_IsExplicitBoundary(self)

    def AddUsingCell(self, cellId):
        r"""
        AddUsingCell(self, cellId)

        Parameters
        ----------
        cellId: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_AddUsingCell(self, cellId)

    def RemoveUsingCell(self, cellId):
        r"""
        RemoveUsingCell(self, cellId)

        Parameters
        ----------
        cellId: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_RemoveUsingCell(self, cellId)

    def IsUsingCell(self, cellId):
        r"""
        IsUsingCell(self, cellId) -> bool

        Parameters
        ----------
        cellId: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_IsUsingCell(self, cellId)

    def GetNumberOfUsingCells(self):
        r"""GetNumberOfUsingCells(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_GetNumberOfUsingCells(self)

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_GetNameOfClass(self)

# Register itkCellInterfaceDQEMCTI2_AutoPointer in _itkQuadEdgeMeshLineCellPython:
_itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI2_AutoPointer_swigregister(itkCellInterfaceDQEMCTI2_AutoPointer)
class itkCellInterfaceDQEMCTI3(object):
    r"""Proxy of C++ itkCellInterfaceDQEMCTI3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def Accept(self, cellId, arg1):
        r"""
        Accept(self, cellId, arg1)

        Parameters
        ----------
        cellId: unsigned long
        arg1: itkCellInterfaceDQEMCTI3::MultiVisitor *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_Accept(self, cellId, arg1)

    def GetType(self):
        r"""GetType(self) -> itkCommonEnums::CellGeometry"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_GetType(self)

    def MakeCopy(self, arg0):
        r"""
        MakeCopy(self, arg0)

        Parameters
        ----------
        arg0: itkCellInterfaceDQEMCTI3_AutoPointer &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_MakeCopy(self, arg0)

    def GetDimension(self):
        r"""GetDimension(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_GetDimension(self)

    def GetInterpolationOrder(self):
        r"""GetInterpolationOrder(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_GetInterpolationOrder(self)

    def GetNumberOfPoints(self):
        r"""GetNumberOfPoints(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_GetNumberOfPoints(self)

    def GetNumberOfBoundaryFeatures(self, dimension):
        r"""
        GetNumberOfBoundaryFeatures(self, dimension) -> unsigned char

        Parameters
        ----------
        dimension: int

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_GetNumberOfBoundaryFeatures(self, dimension)

    def GetBoundaryFeature(self, dimension, arg1, arg2):
        r"""
        GetBoundaryFeature(self, dimension, arg1, arg2) -> bool

        Parameters
        ----------
        dimension: int
        arg1: unsigned char
        arg2: itkCellInterfaceDQEMCTI3_AutoPointer &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_GetBoundaryFeature(self, dimension, arg1, arg2)

    def GetPointIds(self):
        r"""GetPointIds(self) -> unsigned long const *"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_GetPointIds(self)

    def SetPointIds(self, *args):
        r"""
        SetPointIds(self, first)

        Parameters
        ----------
        first: unsigned long const *

        SetPointIds(self, first, last)

        Parameters
        ----------
        first: unsigned long const *
        last: unsigned long const *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_SetPointIds(self, *args)

    def SetPointId(self, localId, arg1):
        r"""
        SetPointId(self, localId, arg1)

        Parameters
        ----------
        localId: int
        arg1: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_SetPointId(self, localId, arg1)

    def PointIdsBegin(self, *args):
        r"""
        PointIdsBegin(self) -> unsigned long
        PointIdsBegin(self) -> unsigned long const *
        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_PointIdsBegin(self, *args)

    def PointIdsEnd(self, *args):
        r"""
        PointIdsEnd(self) -> unsigned long
        PointIdsEnd(self) -> unsigned long const *
        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_PointIdsEnd(self, *args)

    def GetPointIdsContainer(self):
        r"""GetPointIdsContainer(self) -> itkArrayUL"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_GetPointIdsContainer(self)

    def SetPointIdsContainer(self, arg0):
        r"""
        SetPointIdsContainer(self, arg0)

        Parameters
        ----------
        arg0: itkArrayUL const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_SetPointIdsContainer(self, arg0)

    def GetClosestBoundary(self, arg0, arg1, arg2):
        r"""
        GetClosestBoundary(self, arg0, arg1, arg2) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: bool *
        arg2: itkCellInterfaceDQEMCTI3_AutoPointer &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_GetClosestBoundary(self, arg0, arg1, arg2)

    def EvaluatePosition(self, arg0, arg1, arg2, arg3, arg4, arg5):
        r"""
        EvaluatePosition(self, arg0, arg1, arg2, arg3, arg4, arg5) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: itkMapContainerULQEMPF3GQEULULBBT *
        arg2: float *
        arg3: float *
        arg4: double *
        arg5: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_EvaluatePosition(self, arg0, arg1, arg2, arg3, arg4, arg5)

    def EvaluateShapeFunctions(self, arg0, arg1):
        r"""
        EvaluateShapeFunctions(self, arg0, arg1)

        Parameters
        ----------
        arg0: itkArrayF const &
        arg1: itkArrayF &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_EvaluateShapeFunctions(self, arg0, arg1)

    def IntersectWithLine(self, arg0, arg1, arg2, arg3, arg4, arg5):
        r"""
        IntersectWithLine(self, arg0, arg1, arg2, arg3, arg4, arg5) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: float *
        arg2: float
        arg3: float *
        arg4: float *
        arg5: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_IntersectWithLine(self, arg0, arg1, arg2, arg3, arg4, arg5)

    def GetBoundingBox(self, arg0):
        r"""
        GetBoundingBox(self, arg0) -> float *

        Parameters
        ----------
        arg0: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_GetBoundingBox(self, arg0)

    def GetBoundingBoxDiagonalLength2(self):
        r"""GetBoundingBoxDiagonalLength2(self) -> float"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_GetBoundingBoxDiagonalLength2(self)

    def IntersectBoundingBoxWithLine(self, arg0, arg1, arg2, arg3, arg4):
        r"""
        IntersectBoundingBoxWithLine(self, arg0, arg1, arg2, arg3, arg4) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: float *
        arg2: float *
        arg3: float *
        arg4: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_IntersectBoundingBoxWithLine(self, arg0, arg1, arg2, arg3, arg4)

    def IsExplicitBoundary(self):
        r"""IsExplicitBoundary(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_IsExplicitBoundary(self)

    def AddUsingCell(self, cellId):
        r"""
        AddUsingCell(self, cellId)

        Parameters
        ----------
        cellId: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AddUsingCell(self, cellId)

    def RemoveUsingCell(self, cellId):
        r"""
        RemoveUsingCell(self, cellId)

        Parameters
        ----------
        cellId: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_RemoveUsingCell(self, cellId)

    def IsUsingCell(self, cellId):
        r"""
        IsUsingCell(self, cellId) -> bool

        Parameters
        ----------
        cellId: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_IsUsingCell(self, cellId)

    def GetNumberOfUsingCells(self):
        r"""GetNumberOfUsingCells(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_GetNumberOfUsingCells(self)

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_GetNameOfClass(self)
    __swig_destroy__ = _itkQuadEdgeMeshLineCellPython.delete_itkCellInterfaceDQEMCTI3

# Register itkCellInterfaceDQEMCTI3 in _itkQuadEdgeMeshLineCellPython:
_itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_swigregister(itkCellInterfaceDQEMCTI3)
class itkCellInterfaceDQEMCTI3_AutoPointer(object):
    r"""Proxy of C++ itkCellInterfaceDQEMCTI3_AutoPointer class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(self) -> itkCellInterfaceDQEMCTI3_AutoPointer
        __init__(self, p) -> itkCellInterfaceDQEMCTI3_AutoPointer

        Parameters
        ----------
        p: itkCellInterfaceDQEMCTI3_AutoPointer &

        __init__(self, p, takeOwnership) -> itkCellInterfaceDQEMCTI3_AutoPointer

        Parameters
        ----------
        p: itkCellInterfaceDQEMCTI3 *
        takeOwnership: bool

        """
        _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_swiginit(self, _itkQuadEdgeMeshLineCellPython.new_itkCellInterfaceDQEMCTI3_AutoPointer(*args))
    __swig_destroy__ = _itkQuadEdgeMeshLineCellPython.delete_itkCellInterfaceDQEMCTI3_AutoPointer

    def __deref__(self):
        r"""__deref__(self) -> itkCellInterfaceDQEMCTI3"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer___deref__(self)

    def Reset(self):
        r"""Reset(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_Reset(self)

    def TakeOwnership(self, *args):
        r"""
        TakeOwnership(self)
        TakeOwnership(self, objectptr)

        Parameters
        ----------
        objectptr: itkCellInterfaceDQEMCTI3 *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_TakeOwnership(self, *args)

    def TakeNoOwnership(self, objectptr):
        r"""
        TakeNoOwnership(self, objectptr)

        Parameters
        ----------
        objectptr: itkCellInterfaceDQEMCTI3 *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_TakeNoOwnership(self, objectptr)

    def IsOwner(self):
        r"""IsOwner(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_IsOwner(self)

    def ReleaseOwnership(self):
        r"""ReleaseOwnership(self) -> itkCellInterfaceDQEMCTI3"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_ReleaseOwnership(self)

    def GetPointer(self):
        r"""GetPointer(self) -> itkCellInterfaceDQEMCTI3"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_GetPointer(self)

    def __eq__(self, r):
        r"""
        __eq__(self, r) -> bool

        Parameters
        ----------
        r: itkCellInterfaceDQEMCTI3_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer___eq__(self, r)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkCellInterfaceDQEMCTI3_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer___ne__(self, other)

    def __lt__(self, r):
        r"""
        __lt__(self, r) -> bool

        Parameters
        ----------
        r: itkCellInterfaceDQEMCTI3_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer___lt__(self, r)

    def __gt__(self, r):
        r"""
        __gt__(self, r) -> bool

        Parameters
        ----------
        r: itkCellInterfaceDQEMCTI3_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer___gt__(self, r)

    def __le__(self, r):
        r"""
        __le__(self, r) -> bool

        Parameters
        ----------
        r: itkCellInterfaceDQEMCTI3_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer___le__(self, r)

    def __ge__(self, r):
        r"""
        __ge__(self, r) -> bool

        Parameters
        ----------
        r: itkCellInterfaceDQEMCTI3_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer___ge__(self, r)

    def Accept(self, cellId, arg1):
        r"""
        Accept(self, cellId, arg1)

        Parameters
        ----------
        cellId: unsigned long
        arg1: itkCellInterfaceDQEMCTI3::MultiVisitor *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_Accept(self, cellId, arg1)

    def GetType(self):
        r"""GetType(self) -> itkCommonEnums::CellGeometry"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_GetType(self)

    def MakeCopy(self, arg0):
        r"""
        MakeCopy(self, arg0)

        Parameters
        ----------
        arg0: itkCellInterfaceDQEMCTI3_AutoPointer &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_MakeCopy(self, arg0)

    def GetDimension(self):
        r"""GetDimension(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_GetDimension(self)

    def GetInterpolationOrder(self):
        r"""GetInterpolationOrder(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_GetInterpolationOrder(self)

    def GetNumberOfPoints(self):
        r"""GetNumberOfPoints(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_GetNumberOfPoints(self)

    def GetNumberOfBoundaryFeatures(self, dimension):
        r"""
        GetNumberOfBoundaryFeatures(self, dimension) -> unsigned char

        Parameters
        ----------
        dimension: int

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_GetNumberOfBoundaryFeatures(self, dimension)

    def GetBoundaryFeature(self, dimension, arg1, arg2):
        r"""
        GetBoundaryFeature(self, dimension, arg1, arg2) -> bool

        Parameters
        ----------
        dimension: int
        arg1: unsigned char
        arg2: itkCellInterfaceDQEMCTI3_AutoPointer &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_GetBoundaryFeature(self, dimension, arg1, arg2)

    def GetPointIds(self):
        r"""GetPointIds(self) -> unsigned long const *"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_GetPointIds(self)

    def SetPointIds(self, *args):
        r"""
        SetPointIds(self, first)

        Parameters
        ----------
        first: unsigned long const *

        SetPointIds(self, first, last)

        Parameters
        ----------
        first: unsigned long const *
        last: unsigned long const *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_SetPointIds(self, *args)

    def SetPointId(self, localId, arg1):
        r"""
        SetPointId(self, localId, arg1)

        Parameters
        ----------
        localId: int
        arg1: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_SetPointId(self, localId, arg1)

    def PointIdsBegin(self, *args):
        r"""
        PointIdsBegin(self) -> unsigned long
        PointIdsBegin(self) -> unsigned long const *
        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_PointIdsBegin(self, *args)

    def PointIdsEnd(self, *args):
        r"""
        PointIdsEnd(self) -> unsigned long
        PointIdsEnd(self) -> unsigned long const *
        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_PointIdsEnd(self, *args)

    def GetPointIdsContainer(self):
        r"""GetPointIdsContainer(self) -> itkArrayUL"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_GetPointIdsContainer(self)

    def SetPointIdsContainer(self, arg0):
        r"""
        SetPointIdsContainer(self, arg0)

        Parameters
        ----------
        arg0: itkArrayUL const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_SetPointIdsContainer(self, arg0)

    def GetClosestBoundary(self, arg0, arg1, arg2):
        r"""
        GetClosestBoundary(self, arg0, arg1, arg2) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: bool *
        arg2: itkCellInterfaceDQEMCTI3_AutoPointer &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_GetClosestBoundary(self, arg0, arg1, arg2)

    def EvaluatePosition(self, arg0, arg1, arg2, arg3, arg4, arg5):
        r"""
        EvaluatePosition(self, arg0, arg1, arg2, arg3, arg4, arg5) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: itkMapContainerULQEMPF3GQEULULBBT *
        arg2: float *
        arg3: float *
        arg4: double *
        arg5: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_EvaluatePosition(self, arg0, arg1, arg2, arg3, arg4, arg5)

    def EvaluateShapeFunctions(self, arg0, arg1):
        r"""
        EvaluateShapeFunctions(self, arg0, arg1)

        Parameters
        ----------
        arg0: itkArrayF const &
        arg1: itkArrayF &

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_EvaluateShapeFunctions(self, arg0, arg1)

    def IntersectWithLine(self, arg0, arg1, arg2, arg3, arg4, arg5):
        r"""
        IntersectWithLine(self, arg0, arg1, arg2, arg3, arg4, arg5) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: float *
        arg2: float
        arg3: float *
        arg4: float *
        arg5: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_IntersectWithLine(self, arg0, arg1, arg2, arg3, arg4, arg5)

    def GetBoundingBox(self, arg0):
        r"""
        GetBoundingBox(self, arg0) -> float *

        Parameters
        ----------
        arg0: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_GetBoundingBox(self, arg0)

    def GetBoundingBoxDiagonalLength2(self):
        r"""GetBoundingBoxDiagonalLength2(self) -> float"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_GetBoundingBoxDiagonalLength2(self)

    def IntersectBoundingBoxWithLine(self, arg0, arg1, arg2, arg3, arg4):
        r"""
        IntersectBoundingBoxWithLine(self, arg0, arg1, arg2, arg3, arg4) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: float *
        arg2: float *
        arg3: float *
        arg4: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_IntersectBoundingBoxWithLine(self, arg0, arg1, arg2, arg3, arg4)

    def IsExplicitBoundary(self):
        r"""IsExplicitBoundary(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_IsExplicitBoundary(self)

    def AddUsingCell(self, cellId):
        r"""
        AddUsingCell(self, cellId)

        Parameters
        ----------
        cellId: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_AddUsingCell(self, cellId)

    def RemoveUsingCell(self, cellId):
        r"""
        RemoveUsingCell(self, cellId)

        Parameters
        ----------
        cellId: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_RemoveUsingCell(self, cellId)

    def IsUsingCell(self, cellId):
        r"""
        IsUsingCell(self, cellId) -> bool

        Parameters
        ----------
        cellId: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_IsUsingCell(self, cellId)

    def GetNumberOfUsingCells(self):
        r"""GetNumberOfUsingCells(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_GetNumberOfUsingCells(self)

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_GetNameOfClass(self)

# Register itkCellInterfaceDQEMCTI3_AutoPointer in _itkQuadEdgeMeshLineCellPython:
_itkQuadEdgeMeshLineCellPython.itkCellInterfaceDQEMCTI3_AutoPointer_swigregister(itkCellInterfaceDQEMCTI3_AutoPointer)
class itkQuadEdgeMeshLineCellCIDQEMCTI2(itkCellInterfaceDQEMCTI2, itk.itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF):
    r"""Proxy of C++ itkQuadEdgeMeshLineCellCIDQEMCTI2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetQEGeom(self):
        r"""GetQEGeom(self) -> itkGeometricalQuadEdgeULULBBF"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_GetQEGeom(self)

    def __init__(self):
        r"""__init__(self) -> itkQuadEdgeMeshLineCellCIDQEMCTI2"""
        _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_swiginit(self, _itkQuadEdgeMeshLineCellPython.new_itkQuadEdgeMeshLineCellCIDQEMCTI2())
    __swig_destroy__ = _itkQuadEdgeMeshLineCellPython.delete_itkQuadEdgeMeshLineCellCIDQEMCTI2

    def SetIdent(self, cid):
        r"""
        SetIdent(self, cid)

        Parameters
        ----------
        cid: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_SetIdent(self, cid)

    def GetIdent(self):
        r"""GetIdent(self) -> unsigned long"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_GetIdent(self)

    @staticmethod
    def GetTopologyId():
        r"""GetTopologyId() -> itkCommonEnums::CellGeometry"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_GetTopologyId()

    def SetPointIds(self, *args):
        r"""
        SetPointIds(self, first)

        Parameters
        ----------
        first: unsigned long const *

        SetPointIds(self, first, last)

        Parameters
        ----------
        first: unsigned long const *
        last: unsigned long const *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_SetPointIds(self, *args)

    def PointIdsBegin(self, *args):
        r"""
        PointIdsBegin(self) -> unsigned long
        PointIdsBegin(self) -> unsigned long const *
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_PointIdsBegin(self, *args)

    def PointIdsEnd(self, *args):
        r"""
        PointIdsEnd(self) -> unsigned long
        PointIdsEnd(self) -> unsigned long const *
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_PointIdsEnd(self, *args)

    def SynchronizePointsAPI(self):
        r"""SynchronizePointsAPI(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_SynchronizePointsAPI(self)

    def InternalSetPointIds(self, *args):
        r"""
        InternalSetPointIds(self, first)

        Parameters
        ----------
        first: itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >

        InternalSetPointIds(self, first, last)

        Parameters
        ----------
        first: itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        last: itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_InternalSetPointIds(self, *args)

    def InternalGetPointIds(self):
        r"""InternalGetPointIds(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_InternalGetPointIds(self)

    def InternalPointIdsBegin(self, *args):
        r"""
        InternalPointIdsBegin(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        InternalPointIdsBegin(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_InternalPointIdsBegin(self, *args)

    def InternalPointIdsEnd(self, *args):
        r"""
        InternalPointIdsEnd(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        InternalPointIdsEnd(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_InternalPointIdsEnd(self, *args)

# Register itkQuadEdgeMeshLineCellCIDQEMCTI2 in _itkQuadEdgeMeshLineCellPython:
_itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_swigregister(itkQuadEdgeMeshLineCellCIDQEMCTI2)
class itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer(object):
    r"""Proxy of C++ itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(self) -> itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer
        __init__(self, p) -> itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer

        Parameters
        ----------
        p: itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer &

        __init__(self, p, takeOwnership) -> itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer

        Parameters
        ----------
        p: itkQuadEdgeMeshLineCellCIDQEMCTI2 *
        takeOwnership: bool

        """
        _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_swiginit(self, _itkQuadEdgeMeshLineCellPython.new_itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer(*args))
    __swig_destroy__ = _itkQuadEdgeMeshLineCellPython.delete_itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer

    def __deref__(self):
        r"""__deref__(self) -> itkQuadEdgeMeshLineCellCIDQEMCTI2"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer___deref__(self)

    def Reset(self):
        r"""Reset(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_Reset(self)

    def TakeOwnership(self, *args):
        r"""
        TakeOwnership(self)
        TakeOwnership(self, objectptr)

        Parameters
        ----------
        objectptr: itkQuadEdgeMeshLineCellCIDQEMCTI2 *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_TakeOwnership(self, *args)

    def TakeNoOwnership(self, objectptr):
        r"""
        TakeNoOwnership(self, objectptr)

        Parameters
        ----------
        objectptr: itkQuadEdgeMeshLineCellCIDQEMCTI2 *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_TakeNoOwnership(self, objectptr)

    def IsOwner(self):
        r"""IsOwner(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsOwner(self)

    def ReleaseOwnership(self):
        r"""ReleaseOwnership(self) -> itkQuadEdgeMeshLineCellCIDQEMCTI2"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_ReleaseOwnership(self)

    def GetPointer(self):
        r"""GetPointer(self) -> itkQuadEdgeMeshLineCellCIDQEMCTI2"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetPointer(self)

    def __eq__(self, r):
        r"""
        __eq__(self, r) -> bool

        Parameters
        ----------
        r: itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer___eq__(self, r)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer___ne__(self, other)

    def __lt__(self, r):
        r"""
        __lt__(self, r) -> bool

        Parameters
        ----------
        r: itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer___lt__(self, r)

    def __gt__(self, r):
        r"""
        __gt__(self, r) -> bool

        Parameters
        ----------
        r: itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer___gt__(self, r)

    def __le__(self, r):
        r"""
        __le__(self, r) -> bool

        Parameters
        ----------
        r: itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer___le__(self, r)

    def __ge__(self, r):
        r"""
        __ge__(self, r) -> bool

        Parameters
        ----------
        r: itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer___ge__(self, r)

    def GetQEGeom(self):
        r"""GetQEGeom(self) -> itkGeometricalQuadEdgeULULBBF"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetQEGeom(self)

    def SetIdent(self, cid):
        r"""
        SetIdent(self, cid)

        Parameters
        ----------
        cid: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_SetIdent(self, cid)

    def GetIdent(self):
        r"""GetIdent(self) -> unsigned long"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetIdent(self)

    def GetTopologyId(self):
        r"""GetTopologyId(self) -> itkCommonEnums::CellGeometry"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetTopologyId(self)

    def SetPointIds(self, *args):
        r"""
        SetPointIds(self, first)

        Parameters
        ----------
        first: unsigned long const *

        SetPointIds(self, first, last)

        Parameters
        ----------
        first: unsigned long const *
        last: unsigned long const *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_SetPointIds(self, *args)

    def PointIdsBegin(self, *args):
        r"""
        PointIdsBegin(self) -> unsigned long
        PointIdsBegin(self) -> unsigned long const *
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_PointIdsBegin(self, *args)

    def PointIdsEnd(self, *args):
        r"""
        PointIdsEnd(self) -> unsigned long
        PointIdsEnd(self) -> unsigned long const *
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_PointIdsEnd(self, *args)

    def SynchronizePointsAPI(self):
        r"""SynchronizePointsAPI(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_SynchronizePointsAPI(self)

    def InternalSetPointIds(self, *args):
        r"""
        InternalSetPointIds(self, first)

        Parameters
        ----------
        first: itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >

        InternalSetPointIds(self, first, last)

        Parameters
        ----------
        first: itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        last: itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_InternalSetPointIds(self, *args)

    def InternalPointIdsBegin(self, *args):
        r"""
        InternalPointIdsBegin(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        InternalPointIdsBegin(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_InternalPointIdsBegin(self, *args)

    def InternalPointIdsEnd(self, *args):
        r"""
        InternalPointIdsEnd(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        InternalPointIdsEnd(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_InternalPointIdsEnd(self, *args)

    def InternalGetPointIds(self):
        r"""InternalGetPointIds(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_InternalGetPointIds(self)

    def Accept(self, cellId, arg1):
        r"""
        Accept(self, cellId, arg1)

        Parameters
        ----------
        cellId: unsigned long
        arg1: itkCellInterfaceDQEMCTI2::MultiVisitor *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_Accept(self, cellId, arg1)

    def GetType(self):
        r"""GetType(self) -> itkCommonEnums::CellGeometry"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetType(self)

    def MakeCopy(self, arg0):
        r"""
        MakeCopy(self, arg0)

        Parameters
        ----------
        arg0: itkCellInterfaceDQEMCTI2_AutoPointer &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_MakeCopy(self, arg0)

    def GetDimension(self):
        r"""GetDimension(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetDimension(self)

    def GetInterpolationOrder(self):
        r"""GetInterpolationOrder(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetInterpolationOrder(self)

    def GetNumberOfPoints(self):
        r"""GetNumberOfPoints(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetNumberOfPoints(self)

    def GetNumberOfBoundaryFeatures(self, dimension):
        r"""
        GetNumberOfBoundaryFeatures(self, dimension) -> unsigned char

        Parameters
        ----------
        dimension: int

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetNumberOfBoundaryFeatures(self, dimension)

    def GetBoundaryFeature(self, dimension, arg1, arg2):
        r"""
        GetBoundaryFeature(self, dimension, arg1, arg2) -> bool

        Parameters
        ----------
        dimension: int
        arg1: unsigned char
        arg2: itkCellInterfaceDQEMCTI2_AutoPointer &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetBoundaryFeature(self, dimension, arg1, arg2)

    def GetPointIds(self):
        r"""GetPointIds(self) -> unsigned long const *"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetPointIds(self)

    def SetPointId(self, localId, arg1):
        r"""
        SetPointId(self, localId, arg1)

        Parameters
        ----------
        localId: int
        arg1: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_SetPointId(self, localId, arg1)

    def GetPointIdsContainer(self):
        r"""GetPointIdsContainer(self) -> itkArrayUL"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetPointIdsContainer(self)

    def SetPointIdsContainer(self, arg0):
        r"""
        SetPointIdsContainer(self, arg0)

        Parameters
        ----------
        arg0: itkArrayUL const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_SetPointIdsContainer(self, arg0)

    def GetClosestBoundary(self, arg0, arg1, arg2):
        r"""
        GetClosestBoundary(self, arg0, arg1, arg2) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: bool *
        arg2: itkCellInterfaceDQEMCTI2_AutoPointer &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetClosestBoundary(self, arg0, arg1, arg2)

    def EvaluatePosition(self, arg0, arg1, arg2, arg3, arg4, arg5):
        r"""
        EvaluatePosition(self, arg0, arg1, arg2, arg3, arg4, arg5) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: itkMapContainerULQEMPF2GQEULULBBT *
        arg2: float *
        arg3: float *
        arg4: double *
        arg5: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_EvaluatePosition(self, arg0, arg1, arg2, arg3, arg4, arg5)

    def EvaluateShapeFunctions(self, arg0, arg1):
        r"""
        EvaluateShapeFunctions(self, arg0, arg1)

        Parameters
        ----------
        arg0: itkArrayF const &
        arg1: itkArrayF &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_EvaluateShapeFunctions(self, arg0, arg1)

    def IntersectWithLine(self, arg0, arg1, arg2, arg3, arg4, arg5):
        r"""
        IntersectWithLine(self, arg0, arg1, arg2, arg3, arg4, arg5) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: float *
        arg2: float
        arg3: float *
        arg4: float *
        arg5: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IntersectWithLine(self, arg0, arg1, arg2, arg3, arg4, arg5)

    def GetBoundingBox(self, arg0):
        r"""
        GetBoundingBox(self, arg0) -> float *

        Parameters
        ----------
        arg0: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetBoundingBox(self, arg0)

    def GetBoundingBoxDiagonalLength2(self):
        r"""GetBoundingBoxDiagonalLength2(self) -> float"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetBoundingBoxDiagonalLength2(self)

    def IntersectBoundingBoxWithLine(self, arg0, arg1, arg2, arg3, arg4):
        r"""
        IntersectBoundingBoxWithLine(self, arg0, arg1, arg2, arg3, arg4) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: float *
        arg2: float *
        arg3: float *
        arg4: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IntersectBoundingBoxWithLine(self, arg0, arg1, arg2, arg3, arg4)

    def IsExplicitBoundary(self):
        r"""IsExplicitBoundary(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsExplicitBoundary(self)

    def AddUsingCell(self, cellId):
        r"""
        AddUsingCell(self, cellId)

        Parameters
        ----------
        cellId: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_AddUsingCell(self, cellId)

    def RemoveUsingCell(self, cellId):
        r"""
        RemoveUsingCell(self, cellId)

        Parameters
        ----------
        cellId: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_RemoveUsingCell(self, cellId)

    def IsUsingCell(self, cellId):
        r"""
        IsUsingCell(self, cellId) -> bool

        Parameters
        ----------
        cellId: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsUsingCell(self, cellId)

    def GetNumberOfUsingCells(self):
        r"""GetNumberOfUsingCells(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetNumberOfUsingCells(self)

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetNameOfClass(self)

    def BeginGeomOnext(self, *args):
        r"""
        BeginGeomOnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomOnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_BeginGeomOnext(self, *args)

    def EndGeomOnext(self, *args):
        r"""
        EndGeomOnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomOnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_EndGeomOnext(self, *args)

    def BeginGeomSym(self, *args):
        r"""
        BeginGeomSym(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomSym(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_BeginGeomSym(self, *args)

    def EndGeomSym(self, *args):
        r"""
        EndGeomSym(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomSym(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_EndGeomSym(self, *args)

    def BeginGeomLnext(self, *args):
        r"""
        BeginGeomLnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomLnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_BeginGeomLnext(self, *args)

    def EndGeomLnext(self, *args):
        r"""
        EndGeomLnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomLnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_EndGeomLnext(self, *args)

    def BeginGeomRnext(self, *args):
        r"""
        BeginGeomRnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomRnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_BeginGeomRnext(self, *args)

    def EndGeomRnext(self, *args):
        r"""
        EndGeomRnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomRnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_EndGeomRnext(self, *args)

    def BeginGeomDnext(self, *args):
        r"""
        BeginGeomDnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomDnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_BeginGeomDnext(self, *args)

    def EndGeomDnext(self, *args):
        r"""
        EndGeomDnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomDnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_EndGeomDnext(self, *args)

    def BeginGeomOprev(self, *args):
        r"""
        BeginGeomOprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomOprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_BeginGeomOprev(self, *args)

    def EndGeomOprev(self, *args):
        r"""
        EndGeomOprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomOprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_EndGeomOprev(self, *args)

    def BeginGeomLprev(self, *args):
        r"""
        BeginGeomLprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomLprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_BeginGeomLprev(self, *args)

    def EndGeomLprev(self, *args):
        r"""
        EndGeomLprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomLprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_EndGeomLprev(self, *args)

    def BeginGeomRprev(self, *args):
        r"""
        BeginGeomRprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomRprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_BeginGeomRprev(self, *args)

    def EndGeomRprev(self, *args):
        r"""
        EndGeomRprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomRprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_EndGeomRprev(self, *args)

    def BeginGeomDprev(self, *args):
        r"""
        BeginGeomDprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomDprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_BeginGeomDprev(self, *args)

    def EndGeomDprev(self, *args):
        r"""
        EndGeomDprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomDprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_EndGeomDprev(self, *args)

    def BeginGeomInvOnext(self, *args):
        r"""
        BeginGeomInvOnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomInvOnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_BeginGeomInvOnext(self, *args)

    def EndGeomInvOnext(self, *args):
        r"""
        EndGeomInvOnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomInvOnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_EndGeomInvOnext(self, *args)

    def BeginGeomInvLnext(self, *args):
        r"""
        BeginGeomInvLnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomInvLnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_BeginGeomInvLnext(self, *args)

    def EndGeomInvLnext(self, *args):
        r"""
        EndGeomInvLnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomInvLnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_EndGeomInvLnext(self, *args)

    def BeginGeomInvRnext(self, *args):
        r"""
        BeginGeomInvRnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomInvRnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_BeginGeomInvRnext(self, *args)

    def EndGeomInvRnext(self, *args):
        r"""
        EndGeomInvRnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomInvRnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_EndGeomInvRnext(self, *args)

    def BeginGeomInvDnext(self, *args):
        r"""
        BeginGeomInvDnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomInvDnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_BeginGeomInvDnext(self, *args)

    def EndGeomInvDnext(self, *args):
        r"""
        EndGeomInvDnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomInvDnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_EndGeomInvDnext(self, *args)

    def GetOnext(self, *args):
        r"""
        GetOnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetOnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetOnext(self, *args)

    def GetRot(self, *args):
        r"""
        GetRot(self) -> itkGeometricalQuadEdgeULULBBT
        GetRot(self) -> itkGeometricalQuadEdgeULULBBT
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetRot(self, *args)

    def GetSym(self, *args):
        r"""
        GetSym(self) -> itkGeometricalQuadEdgeULULBBF
        GetSym(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetSym(self, *args)

    def GetLnext(self, *args):
        r"""
        GetLnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetLnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetLnext(self, *args)

    def GetRnext(self, *args):
        r"""
        GetRnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetRnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetRnext(self, *args)

    def GetDnext(self, *args):
        r"""
        GetDnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetDnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetDnext(self, *args)

    def GetOprev(self, *args):
        r"""
        GetOprev(self) -> itkGeometricalQuadEdgeULULBBF
        GetOprev(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetOprev(self, *args)

    def GetLprev(self, *args):
        r"""
        GetLprev(self) -> itkGeometricalQuadEdgeULULBBF
        GetLprev(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetLprev(self, *args)

    def GetRprev(self, *args):
        r"""
        GetRprev(self) -> itkGeometricalQuadEdgeULULBBF
        GetRprev(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetRprev(self, *args)

    def GetDprev(self, *args):
        r"""
        GetDprev(self) -> itkGeometricalQuadEdgeULULBBF
        GetDprev(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetDprev(self, *args)

    def GetInvRot(self, *args):
        r"""
        GetInvRot(self) -> itkGeometricalQuadEdgeULULBBT
        GetInvRot(self) -> itkGeometricalQuadEdgeULULBBT
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetInvRot(self, *args)

    def GetInvOnext(self, *args):
        r"""
        GetInvOnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetInvOnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetInvOnext(self, *args)

    def GetInvLnext(self, *args):
        r"""
        GetInvLnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetInvLnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetInvLnext(self, *args)

    def GetInvRnext(self, *args):
        r"""
        GetInvRnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetInvRnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetInvRnext(self, *args)

    def GetInvDnext(self, *args):
        r"""
        GetInvDnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetInvDnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetInvDnext(self, *args)

    def SetOrigin(self, v):
        r"""
        SetOrigin(self, v)

        Parameters
        ----------
        v: unsigned long const

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_SetOrigin(self, v)

    def SetDestination(self, v):
        r"""
        SetDestination(self, v)

        Parameters
        ----------
        v: unsigned long const

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_SetDestination(self, v)

    def SetRight(self, v):
        r"""
        SetRight(self, v)

        Parameters
        ----------
        v: unsigned long const

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_SetRight(self, v)

    def SetLeft(self, v):
        r"""
        SetLeft(self, v)

        Parameters
        ----------
        v: unsigned long const

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_SetLeft(self, v)

    def SetLnextRingWithSameLeftFace(self, faceGeom, maxSize=100):
        r"""
        SetLnextRingWithSameLeftFace(self, faceGeom, maxSize=100) -> bool

        Parameters
        ----------
        faceGeom: unsigned long const
        maxSize: int

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_SetLnextRingWithSameLeftFace(self, faceGeom, maxSize)

    def UnsetOrigin(self):
        r"""UnsetOrigin(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_UnsetOrigin(self)

    def UnsetDestination(self):
        r"""UnsetDestination(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_UnsetDestination(self)

    def UnsetRight(self):
        r"""UnsetRight(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_UnsetRight(self)

    def UnsetLeft(self):
        r"""UnsetLeft(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_UnsetLeft(self)

    def GetOrigin(self):
        r"""GetOrigin(self) -> unsigned long const"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetOrigin(self)

    def GetDestination(self):
        r"""GetDestination(self) -> unsigned long const"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetDestination(self)

    def GetRight(self):
        r"""GetRight(self) -> unsigned long const"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetRight(self)

    def GetLeft(self):
        r"""GetLeft(self) -> unsigned long const"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetLeft(self)

    def IsOriginSet(self):
        r"""IsOriginSet(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsOriginSet(self)

    def IsDestinationSet(self):
        r"""IsDestinationSet(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsDestinationSet(self)

    def IsRightSet(self):
        r"""IsRightSet(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsRightSet(self)

    def IsLeftSet(self):
        r"""IsLeftSet(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsLeftSet(self)

    def SetPrimalData(self, *args):
        r"""
        SetPrimalData(self, data)

        Parameters
        ----------
        data: bool const

        SetPrimalData(self)
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_SetPrimalData(self, *args)

    def SetDualData(self, *args):
        r"""
        SetDualData(self, data)

        Parameters
        ----------
        data: bool const

        SetDualData(self)
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_SetDualData(self, *args)

    def UnsetPrimalData(self):
        r"""UnsetPrimalData(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_UnsetPrimalData(self)

    def UnsetDualData(self):
        r"""UnsetDualData(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_UnsetDualData(self)

    def GetPrimalData(self):
        r"""GetPrimalData(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetPrimalData(self)

    def GetDualData(self):
        r"""GetDualData(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetDualData(self)

    def IsPrimalDataSet(self):
        r"""IsPrimalDataSet(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsPrimalDataSet(self)

    def IsDualDataSet(self):
        r"""IsDualDataSet(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsDualDataSet(self)

    def IsWire(self):
        r"""IsWire(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsWire(self)

    def IsAtBorder(self):
        r"""IsAtBorder(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsAtBorder(self)

    def IsInternal(self):
        r"""IsInternal(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsInternal(self)

    def IsOriginInternal(self):
        r"""IsOriginInternal(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsOriginInternal(self)

    def IsLnextSharingSameFace(self, maxSize=100):
        r"""
        IsLnextSharingSameFace(self, maxSize=100) -> bool

        Parameters
        ----------
        maxSize: int

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsLnextSharingSameFace(self, maxSize)

    def IsLnextOfTriangle(self):
        r"""IsLnextOfTriangle(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsLnextOfTriangle(self)

    def IsInOnextRing(self, arg0):
        r"""
        IsInOnextRing(self, arg0) -> bool

        Parameters
        ----------
        arg0: itkGeometricalQuadEdgeULULBBF *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsInOnextRing(self, arg0)

    def IsInLnextRing(self, arg0):
        r"""
        IsInLnextRing(self, arg0) -> bool

        Parameters
        ----------
        arg0: itkGeometricalQuadEdgeULULBBF *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsInLnextRing(self, arg0)

    def GetNextBorderEdgeWithUnsetLeft(self, edgeTest=None):
        r"""
        GetNextBorderEdgeWithUnsetLeft(self, edgeTest=None) -> itkGeometricalQuadEdgeULULBBF

        Parameters
        ----------
        edgeTest: itkGeometricalQuadEdgeULULBBF *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetNextBorderEdgeWithUnsetLeft(self, edgeTest)

    def InsertAfterNextBorderEdgeWithUnsetLeft(self, isol, hint=None):
        r"""
        InsertAfterNextBorderEdgeWithUnsetLeft(self, isol, hint=None) -> bool

        Parameters
        ----------
        isol: itkGeometricalQuadEdgeULULBBF *
        hint: itkGeometricalQuadEdgeULULBBF *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_InsertAfterNextBorderEdgeWithUnsetLeft(self, isol, hint)

    def ReorderOnextRingBeforeAddFace(self, second):
        r"""
        ReorderOnextRingBeforeAddFace(self, second) -> bool

        Parameters
        ----------
        second: itkGeometricalQuadEdgeULULBBF *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_ReorderOnextRingBeforeAddFace(self, second)

    def IsOriginDisconnected(self):
        r"""IsOriginDisconnected(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsOriginDisconnected(self)

    def IsDestinationDisconnected(self):
        r"""IsDestinationDisconnected(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsDestinationDisconnected(self)

    def IsDisconnected(self):
        r"""IsDisconnected(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsDisconnected(self)

    def Disconnect(self):
        r"""Disconnect(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_Disconnect(self)

    def BeginOnext(self, *args):
        r"""
        BeginOnext(self) -> itk::QuadEdgeMeshIterator< itk::QuadEdge >
        BeginOnext(self) -> itk::QuadEdgeMeshConstIterator< itk::QuadEdge >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_BeginOnext(self, *args)

    def EndOnext(self, *args):
        r"""
        EndOnext(self) -> itk::QuadEdgeMeshIterator< itk::QuadEdge >
        EndOnext(self) -> itk::QuadEdgeMeshConstIterator< itk::QuadEdge >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_EndOnext(self, *args)

    def SetOnext(self, onext):
        r"""
        SetOnext(self, onext)

        Parameters
        ----------
        onext: itkQuadEdge *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_SetOnext(self, onext)

    def SetRot(self, rot):
        r"""
        SetRot(self, rot)

        Parameters
        ----------
        rot: itkQuadEdge *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_SetRot(self, rot)

    def Splice(self, b):
        r"""
        Splice(self, b)

        Parameters
        ----------
        b: itkQuadEdge *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_Splice(self, b)

    def IsHalfEdge(self):
        r"""IsHalfEdge(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsHalfEdge(self)

    def IsIsolated(self):
        r"""IsIsolated(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsIsolated(self)

    def IsEdgeInOnextRing(self, testEdge):
        r"""
        IsEdgeInOnextRing(self, testEdge) -> bool

        Parameters
        ----------
        testEdge: itkQuadEdge *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsEdgeInOnextRing(self, testEdge)

    def IsLnextGivenSizeCyclic(self, size):
        r"""
        IsLnextGivenSizeCyclic(self, size) -> bool

        Parameters
        ----------
        size: int const

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_IsLnextGivenSizeCyclic(self, size)

    def GetOrder(self):
        r"""GetOrder(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_GetOrder(self)

# Register itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer in _itkQuadEdgeMeshLineCellPython:
_itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer_swigregister(itkQuadEdgeMeshLineCellCIDQEMCTI2_AutoPointer)
class itkQuadEdgeMeshLineCellCIDQEMCTI3(itkCellInterfaceDQEMCTI3, itk.itkGeometricalQuadEdgePython.itkGeometricalQuadEdgeULULBBF):
    r"""Proxy of C++ itkQuadEdgeMeshLineCellCIDQEMCTI3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetQEGeom(self):
        r"""GetQEGeom(self) -> itkGeometricalQuadEdgeULULBBF"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_GetQEGeom(self)

    def __init__(self):
        r"""__init__(self) -> itkQuadEdgeMeshLineCellCIDQEMCTI3"""
        _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_swiginit(self, _itkQuadEdgeMeshLineCellPython.new_itkQuadEdgeMeshLineCellCIDQEMCTI3())
    __swig_destroy__ = _itkQuadEdgeMeshLineCellPython.delete_itkQuadEdgeMeshLineCellCIDQEMCTI3

    def SetIdent(self, cid):
        r"""
        SetIdent(self, cid)

        Parameters
        ----------
        cid: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_SetIdent(self, cid)

    def GetIdent(self):
        r"""GetIdent(self) -> unsigned long"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_GetIdent(self)

    @staticmethod
    def GetTopologyId():
        r"""GetTopologyId() -> itkCommonEnums::CellGeometry"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_GetTopologyId()

    def SetPointIds(self, *args):
        r"""
        SetPointIds(self, first)

        Parameters
        ----------
        first: unsigned long const *

        SetPointIds(self, first, last)

        Parameters
        ----------
        first: unsigned long const *
        last: unsigned long const *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_SetPointIds(self, *args)

    def PointIdsBegin(self, *args):
        r"""
        PointIdsBegin(self) -> unsigned long
        PointIdsBegin(self) -> unsigned long const *
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_PointIdsBegin(self, *args)

    def PointIdsEnd(self, *args):
        r"""
        PointIdsEnd(self) -> unsigned long
        PointIdsEnd(self) -> unsigned long const *
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_PointIdsEnd(self, *args)

    def SynchronizePointsAPI(self):
        r"""SynchronizePointsAPI(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_SynchronizePointsAPI(self)

    def InternalSetPointIds(self, *args):
        r"""
        InternalSetPointIds(self, first)

        Parameters
        ----------
        first: itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >

        InternalSetPointIds(self, first, last)

        Parameters
        ----------
        first: itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        last: itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_InternalSetPointIds(self, *args)

    def InternalGetPointIds(self):
        r"""InternalGetPointIds(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_InternalGetPointIds(self)

    def InternalPointIdsBegin(self, *args):
        r"""
        InternalPointIdsBegin(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        InternalPointIdsBegin(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_InternalPointIdsBegin(self, *args)

    def InternalPointIdsEnd(self, *args):
        r"""
        InternalPointIdsEnd(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        InternalPointIdsEnd(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_InternalPointIdsEnd(self, *args)

# Register itkQuadEdgeMeshLineCellCIDQEMCTI3 in _itkQuadEdgeMeshLineCellPython:
_itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_swigregister(itkQuadEdgeMeshLineCellCIDQEMCTI3)
class itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer(object):
    r"""Proxy of C++ itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(self) -> itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer
        __init__(self, p) -> itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer

        Parameters
        ----------
        p: itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer &

        __init__(self, p, takeOwnership) -> itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer

        Parameters
        ----------
        p: itkQuadEdgeMeshLineCellCIDQEMCTI3 *
        takeOwnership: bool

        """
        _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_swiginit(self, _itkQuadEdgeMeshLineCellPython.new_itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer(*args))
    __swig_destroy__ = _itkQuadEdgeMeshLineCellPython.delete_itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer

    def __deref__(self):
        r"""__deref__(self) -> itkQuadEdgeMeshLineCellCIDQEMCTI3"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer___deref__(self)

    def Reset(self):
        r"""Reset(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_Reset(self)

    def TakeOwnership(self, *args):
        r"""
        TakeOwnership(self)
        TakeOwnership(self, objectptr)

        Parameters
        ----------
        objectptr: itkQuadEdgeMeshLineCellCIDQEMCTI3 *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_TakeOwnership(self, *args)

    def TakeNoOwnership(self, objectptr):
        r"""
        TakeNoOwnership(self, objectptr)

        Parameters
        ----------
        objectptr: itkQuadEdgeMeshLineCellCIDQEMCTI3 *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_TakeNoOwnership(self, objectptr)

    def IsOwner(self):
        r"""IsOwner(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsOwner(self)

    def ReleaseOwnership(self):
        r"""ReleaseOwnership(self) -> itkQuadEdgeMeshLineCellCIDQEMCTI3"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_ReleaseOwnership(self)

    def GetPointer(self):
        r"""GetPointer(self) -> itkQuadEdgeMeshLineCellCIDQEMCTI3"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetPointer(self)

    def __eq__(self, r):
        r"""
        __eq__(self, r) -> bool

        Parameters
        ----------
        r: itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer___eq__(self, r)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer___ne__(self, other)

    def __lt__(self, r):
        r"""
        __lt__(self, r) -> bool

        Parameters
        ----------
        r: itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer___lt__(self, r)

    def __gt__(self, r):
        r"""
        __gt__(self, r) -> bool

        Parameters
        ----------
        r: itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer___gt__(self, r)

    def __le__(self, r):
        r"""
        __le__(self, r) -> bool

        Parameters
        ----------
        r: itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer___le__(self, r)

    def __ge__(self, r):
        r"""
        __ge__(self, r) -> bool

        Parameters
        ----------
        r: itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer___ge__(self, r)

    def GetQEGeom(self):
        r"""GetQEGeom(self) -> itkGeometricalQuadEdgeULULBBF"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetQEGeom(self)

    def SetIdent(self, cid):
        r"""
        SetIdent(self, cid)

        Parameters
        ----------
        cid: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_SetIdent(self, cid)

    def GetIdent(self):
        r"""GetIdent(self) -> unsigned long"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetIdent(self)

    def GetTopologyId(self):
        r"""GetTopologyId(self) -> itkCommonEnums::CellGeometry"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetTopologyId(self)

    def SetPointIds(self, *args):
        r"""
        SetPointIds(self, first)

        Parameters
        ----------
        first: unsigned long const *

        SetPointIds(self, first, last)

        Parameters
        ----------
        first: unsigned long const *
        last: unsigned long const *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_SetPointIds(self, *args)

    def PointIdsBegin(self, *args):
        r"""
        PointIdsBegin(self) -> unsigned long
        PointIdsBegin(self) -> unsigned long const *
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_PointIdsBegin(self, *args)

    def PointIdsEnd(self, *args):
        r"""
        PointIdsEnd(self) -> unsigned long
        PointIdsEnd(self) -> unsigned long const *
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_PointIdsEnd(self, *args)

    def SynchronizePointsAPI(self):
        r"""SynchronizePointsAPI(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_SynchronizePointsAPI(self)

    def InternalSetPointIds(self, *args):
        r"""
        InternalSetPointIds(self, first)

        Parameters
        ----------
        first: itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >

        InternalSetPointIds(self, first, last)

        Parameters
        ----------
        first: itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        last: itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_InternalSetPointIds(self, *args)

    def InternalPointIdsBegin(self, *args):
        r"""
        InternalPointIdsBegin(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        InternalPointIdsBegin(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_InternalPointIdsBegin(self, *args)

    def InternalPointIdsEnd(self, *args):
        r"""
        InternalPointIdsEnd(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        InternalPointIdsEnd(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_InternalPointIdsEnd(self, *args)

    def InternalGetPointIds(self):
        r"""InternalGetPointIds(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_InternalGetPointIds(self)

    def Accept(self, cellId, arg1):
        r"""
        Accept(self, cellId, arg1)

        Parameters
        ----------
        cellId: unsigned long
        arg1: itkCellInterfaceDQEMCTI3::MultiVisitor *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_Accept(self, cellId, arg1)

    def GetType(self):
        r"""GetType(self) -> itkCommonEnums::CellGeometry"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetType(self)

    def MakeCopy(self, arg0):
        r"""
        MakeCopy(self, arg0)

        Parameters
        ----------
        arg0: itkCellInterfaceDQEMCTI3_AutoPointer &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_MakeCopy(self, arg0)

    def GetDimension(self):
        r"""GetDimension(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetDimension(self)

    def GetInterpolationOrder(self):
        r"""GetInterpolationOrder(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetInterpolationOrder(self)

    def GetNumberOfPoints(self):
        r"""GetNumberOfPoints(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetNumberOfPoints(self)

    def GetNumberOfBoundaryFeatures(self, dimension):
        r"""
        GetNumberOfBoundaryFeatures(self, dimension) -> unsigned char

        Parameters
        ----------
        dimension: int

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetNumberOfBoundaryFeatures(self, dimension)

    def GetBoundaryFeature(self, dimension, arg1, arg2):
        r"""
        GetBoundaryFeature(self, dimension, arg1, arg2) -> bool

        Parameters
        ----------
        dimension: int
        arg1: unsigned char
        arg2: itkCellInterfaceDQEMCTI3_AutoPointer &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetBoundaryFeature(self, dimension, arg1, arg2)

    def GetPointIds(self):
        r"""GetPointIds(self) -> unsigned long const *"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetPointIds(self)

    def SetPointId(self, localId, arg1):
        r"""
        SetPointId(self, localId, arg1)

        Parameters
        ----------
        localId: int
        arg1: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_SetPointId(self, localId, arg1)

    def GetPointIdsContainer(self):
        r"""GetPointIdsContainer(self) -> itkArrayUL"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetPointIdsContainer(self)

    def SetPointIdsContainer(self, arg0):
        r"""
        SetPointIdsContainer(self, arg0)

        Parameters
        ----------
        arg0: itkArrayUL const &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_SetPointIdsContainer(self, arg0)

    def GetClosestBoundary(self, arg0, arg1, arg2):
        r"""
        GetClosestBoundary(self, arg0, arg1, arg2) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: bool *
        arg2: itkCellInterfaceDQEMCTI3_AutoPointer &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetClosestBoundary(self, arg0, arg1, arg2)

    def EvaluatePosition(self, arg0, arg1, arg2, arg3, arg4, arg5):
        r"""
        EvaluatePosition(self, arg0, arg1, arg2, arg3, arg4, arg5) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: itkMapContainerULQEMPF3GQEULULBBT *
        arg2: float *
        arg3: float *
        arg4: double *
        arg5: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_EvaluatePosition(self, arg0, arg1, arg2, arg3, arg4, arg5)

    def EvaluateShapeFunctions(self, arg0, arg1):
        r"""
        EvaluateShapeFunctions(self, arg0, arg1)

        Parameters
        ----------
        arg0: itkArrayF const &
        arg1: itkArrayF &

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_EvaluateShapeFunctions(self, arg0, arg1)

    def IntersectWithLine(self, arg0, arg1, arg2, arg3, arg4, arg5):
        r"""
        IntersectWithLine(self, arg0, arg1, arg2, arg3, arg4, arg5) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: float *
        arg2: float
        arg3: float *
        arg4: float *
        arg5: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IntersectWithLine(self, arg0, arg1, arg2, arg3, arg4, arg5)

    def GetBoundingBox(self, arg0):
        r"""
        GetBoundingBox(self, arg0) -> float *

        Parameters
        ----------
        arg0: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetBoundingBox(self, arg0)

    def GetBoundingBoxDiagonalLength2(self):
        r"""GetBoundingBoxDiagonalLength2(self) -> float"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetBoundingBoxDiagonalLength2(self)

    def IntersectBoundingBoxWithLine(self, arg0, arg1, arg2, arg3, arg4):
        r"""
        IntersectBoundingBoxWithLine(self, arg0, arg1, arg2, arg3, arg4) -> bool

        Parameters
        ----------
        arg0: float *
        arg1: float *
        arg2: float *
        arg3: float *
        arg4: float *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IntersectBoundingBoxWithLine(self, arg0, arg1, arg2, arg3, arg4)

    def IsExplicitBoundary(self):
        r"""IsExplicitBoundary(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsExplicitBoundary(self)

    def AddUsingCell(self, cellId):
        r"""
        AddUsingCell(self, cellId)

        Parameters
        ----------
        cellId: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_AddUsingCell(self, cellId)

    def RemoveUsingCell(self, cellId):
        r"""
        RemoveUsingCell(self, cellId)

        Parameters
        ----------
        cellId: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_RemoveUsingCell(self, cellId)

    def IsUsingCell(self, cellId):
        r"""
        IsUsingCell(self, cellId) -> bool

        Parameters
        ----------
        cellId: unsigned long

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsUsingCell(self, cellId)

    def GetNumberOfUsingCells(self):
        r"""GetNumberOfUsingCells(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetNumberOfUsingCells(self)

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetNameOfClass(self)

    def BeginGeomOnext(self, *args):
        r"""
        BeginGeomOnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomOnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_BeginGeomOnext(self, *args)

    def EndGeomOnext(self, *args):
        r"""
        EndGeomOnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomOnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_EndGeomOnext(self, *args)

    def BeginGeomSym(self, *args):
        r"""
        BeginGeomSym(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomSym(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_BeginGeomSym(self, *args)

    def EndGeomSym(self, *args):
        r"""
        EndGeomSym(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomSym(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_EndGeomSym(self, *args)

    def BeginGeomLnext(self, *args):
        r"""
        BeginGeomLnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomLnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_BeginGeomLnext(self, *args)

    def EndGeomLnext(self, *args):
        r"""
        EndGeomLnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomLnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_EndGeomLnext(self, *args)

    def BeginGeomRnext(self, *args):
        r"""
        BeginGeomRnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomRnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_BeginGeomRnext(self, *args)

    def EndGeomRnext(self, *args):
        r"""
        EndGeomRnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomRnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_EndGeomRnext(self, *args)

    def BeginGeomDnext(self, *args):
        r"""
        BeginGeomDnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomDnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_BeginGeomDnext(self, *args)

    def EndGeomDnext(self, *args):
        r"""
        EndGeomDnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomDnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_EndGeomDnext(self, *args)

    def BeginGeomOprev(self, *args):
        r"""
        BeginGeomOprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomOprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_BeginGeomOprev(self, *args)

    def EndGeomOprev(self, *args):
        r"""
        EndGeomOprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomOprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_EndGeomOprev(self, *args)

    def BeginGeomLprev(self, *args):
        r"""
        BeginGeomLprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomLprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_BeginGeomLprev(self, *args)

    def EndGeomLprev(self, *args):
        r"""
        EndGeomLprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomLprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_EndGeomLprev(self, *args)

    def BeginGeomRprev(self, *args):
        r"""
        BeginGeomRprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomRprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_BeginGeomRprev(self, *args)

    def EndGeomRprev(self, *args):
        r"""
        EndGeomRprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomRprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_EndGeomRprev(self, *args)

    def BeginGeomDprev(self, *args):
        r"""
        BeginGeomDprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomDprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_BeginGeomDprev(self, *args)

    def EndGeomDprev(self, *args):
        r"""
        EndGeomDprev(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomDprev(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_EndGeomDprev(self, *args)

    def BeginGeomInvOnext(self, *args):
        r"""
        BeginGeomInvOnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomInvOnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_BeginGeomInvOnext(self, *args)

    def EndGeomInvOnext(self, *args):
        r"""
        EndGeomInvOnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomInvOnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_EndGeomInvOnext(self, *args)

    def BeginGeomInvLnext(self, *args):
        r"""
        BeginGeomInvLnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomInvLnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_BeginGeomInvLnext(self, *args)

    def EndGeomInvLnext(self, *args):
        r"""
        EndGeomInvLnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomInvLnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_EndGeomInvLnext(self, *args)

    def BeginGeomInvRnext(self, *args):
        r"""
        BeginGeomInvRnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomInvRnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_BeginGeomInvRnext(self, *args)

    def EndGeomInvRnext(self, *args):
        r"""
        EndGeomInvRnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomInvRnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_EndGeomInvRnext(self, *args)

    def BeginGeomInvDnext(self, *args):
        r"""
        BeginGeomInvDnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        BeginGeomInvDnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_BeginGeomInvDnext(self, *args)

    def EndGeomInvDnext(self, *args):
        r"""
        EndGeomInvDnext(self) -> itk::QuadEdgeMeshIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        EndGeomInvDnext(self) -> itk::QuadEdgeMeshConstIteratorGeom< itk::GeometricalQuadEdge< unsigned long,unsigned long,bool,bool > >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_EndGeomInvDnext(self, *args)

    def GetOnext(self, *args):
        r"""
        GetOnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetOnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetOnext(self, *args)

    def GetRot(self, *args):
        r"""
        GetRot(self) -> itkGeometricalQuadEdgeULULBBT
        GetRot(self) -> itkGeometricalQuadEdgeULULBBT
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetRot(self, *args)

    def GetSym(self, *args):
        r"""
        GetSym(self) -> itkGeometricalQuadEdgeULULBBF
        GetSym(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetSym(self, *args)

    def GetLnext(self, *args):
        r"""
        GetLnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetLnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetLnext(self, *args)

    def GetRnext(self, *args):
        r"""
        GetRnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetRnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetRnext(self, *args)

    def GetDnext(self, *args):
        r"""
        GetDnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetDnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetDnext(self, *args)

    def GetOprev(self, *args):
        r"""
        GetOprev(self) -> itkGeometricalQuadEdgeULULBBF
        GetOprev(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetOprev(self, *args)

    def GetLprev(self, *args):
        r"""
        GetLprev(self) -> itkGeometricalQuadEdgeULULBBF
        GetLprev(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetLprev(self, *args)

    def GetRprev(self, *args):
        r"""
        GetRprev(self) -> itkGeometricalQuadEdgeULULBBF
        GetRprev(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetRprev(self, *args)

    def GetDprev(self, *args):
        r"""
        GetDprev(self) -> itkGeometricalQuadEdgeULULBBF
        GetDprev(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetDprev(self, *args)

    def GetInvRot(self, *args):
        r"""
        GetInvRot(self) -> itkGeometricalQuadEdgeULULBBT
        GetInvRot(self) -> itkGeometricalQuadEdgeULULBBT
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetInvRot(self, *args)

    def GetInvOnext(self, *args):
        r"""
        GetInvOnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetInvOnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetInvOnext(self, *args)

    def GetInvLnext(self, *args):
        r"""
        GetInvLnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetInvLnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetInvLnext(self, *args)

    def GetInvRnext(self, *args):
        r"""
        GetInvRnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetInvRnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetInvRnext(self, *args)

    def GetInvDnext(self, *args):
        r"""
        GetInvDnext(self) -> itkGeometricalQuadEdgeULULBBF
        GetInvDnext(self) -> itkGeometricalQuadEdgeULULBBF
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetInvDnext(self, *args)

    def SetOrigin(self, v):
        r"""
        SetOrigin(self, v)

        Parameters
        ----------
        v: unsigned long const

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_SetOrigin(self, v)

    def SetDestination(self, v):
        r"""
        SetDestination(self, v)

        Parameters
        ----------
        v: unsigned long const

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_SetDestination(self, v)

    def SetRight(self, v):
        r"""
        SetRight(self, v)

        Parameters
        ----------
        v: unsigned long const

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_SetRight(self, v)

    def SetLeft(self, v):
        r"""
        SetLeft(self, v)

        Parameters
        ----------
        v: unsigned long const

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_SetLeft(self, v)

    def SetLnextRingWithSameLeftFace(self, faceGeom, maxSize=100):
        r"""
        SetLnextRingWithSameLeftFace(self, faceGeom, maxSize=100) -> bool

        Parameters
        ----------
        faceGeom: unsigned long const
        maxSize: int

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_SetLnextRingWithSameLeftFace(self, faceGeom, maxSize)

    def UnsetOrigin(self):
        r"""UnsetOrigin(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_UnsetOrigin(self)

    def UnsetDestination(self):
        r"""UnsetDestination(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_UnsetDestination(self)

    def UnsetRight(self):
        r"""UnsetRight(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_UnsetRight(self)

    def UnsetLeft(self):
        r"""UnsetLeft(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_UnsetLeft(self)

    def GetOrigin(self):
        r"""GetOrigin(self) -> unsigned long const"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetOrigin(self)

    def GetDestination(self):
        r"""GetDestination(self) -> unsigned long const"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetDestination(self)

    def GetRight(self):
        r"""GetRight(self) -> unsigned long const"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetRight(self)

    def GetLeft(self):
        r"""GetLeft(self) -> unsigned long const"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetLeft(self)

    def IsOriginSet(self):
        r"""IsOriginSet(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsOriginSet(self)

    def IsDestinationSet(self):
        r"""IsDestinationSet(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsDestinationSet(self)

    def IsRightSet(self):
        r"""IsRightSet(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsRightSet(self)

    def IsLeftSet(self):
        r"""IsLeftSet(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsLeftSet(self)

    def SetPrimalData(self, *args):
        r"""
        SetPrimalData(self, data)

        Parameters
        ----------
        data: bool const

        SetPrimalData(self)
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_SetPrimalData(self, *args)

    def SetDualData(self, *args):
        r"""
        SetDualData(self, data)

        Parameters
        ----------
        data: bool const

        SetDualData(self)
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_SetDualData(self, *args)

    def UnsetPrimalData(self):
        r"""UnsetPrimalData(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_UnsetPrimalData(self)

    def UnsetDualData(self):
        r"""UnsetDualData(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_UnsetDualData(self)

    def GetPrimalData(self):
        r"""GetPrimalData(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetPrimalData(self)

    def GetDualData(self):
        r"""GetDualData(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetDualData(self)

    def IsPrimalDataSet(self):
        r"""IsPrimalDataSet(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsPrimalDataSet(self)

    def IsDualDataSet(self):
        r"""IsDualDataSet(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsDualDataSet(self)

    def IsWire(self):
        r"""IsWire(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsWire(self)

    def IsAtBorder(self):
        r"""IsAtBorder(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsAtBorder(self)

    def IsInternal(self):
        r"""IsInternal(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsInternal(self)

    def IsOriginInternal(self):
        r"""IsOriginInternal(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsOriginInternal(self)

    def IsLnextSharingSameFace(self, maxSize=100):
        r"""
        IsLnextSharingSameFace(self, maxSize=100) -> bool

        Parameters
        ----------
        maxSize: int

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsLnextSharingSameFace(self, maxSize)

    def IsLnextOfTriangle(self):
        r"""IsLnextOfTriangle(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsLnextOfTriangle(self)

    def IsInOnextRing(self, arg0):
        r"""
        IsInOnextRing(self, arg0) -> bool

        Parameters
        ----------
        arg0: itkGeometricalQuadEdgeULULBBF *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsInOnextRing(self, arg0)

    def IsInLnextRing(self, arg0):
        r"""
        IsInLnextRing(self, arg0) -> bool

        Parameters
        ----------
        arg0: itkGeometricalQuadEdgeULULBBF *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsInLnextRing(self, arg0)

    def GetNextBorderEdgeWithUnsetLeft(self, edgeTest=None):
        r"""
        GetNextBorderEdgeWithUnsetLeft(self, edgeTest=None) -> itkGeometricalQuadEdgeULULBBF

        Parameters
        ----------
        edgeTest: itkGeometricalQuadEdgeULULBBF *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetNextBorderEdgeWithUnsetLeft(self, edgeTest)

    def InsertAfterNextBorderEdgeWithUnsetLeft(self, isol, hint=None):
        r"""
        InsertAfterNextBorderEdgeWithUnsetLeft(self, isol, hint=None) -> bool

        Parameters
        ----------
        isol: itkGeometricalQuadEdgeULULBBF *
        hint: itkGeometricalQuadEdgeULULBBF *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_InsertAfterNextBorderEdgeWithUnsetLeft(self, isol, hint)

    def ReorderOnextRingBeforeAddFace(self, second):
        r"""
        ReorderOnextRingBeforeAddFace(self, second) -> bool

        Parameters
        ----------
        second: itkGeometricalQuadEdgeULULBBF *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_ReorderOnextRingBeforeAddFace(self, second)

    def IsOriginDisconnected(self):
        r"""IsOriginDisconnected(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsOriginDisconnected(self)

    def IsDestinationDisconnected(self):
        r"""IsDestinationDisconnected(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsDestinationDisconnected(self)

    def IsDisconnected(self):
        r"""IsDisconnected(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsDisconnected(self)

    def Disconnect(self):
        r"""Disconnect(self)"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_Disconnect(self)

    def BeginOnext(self, *args):
        r"""
        BeginOnext(self) -> itk::QuadEdgeMeshIterator< itk::QuadEdge >
        BeginOnext(self) -> itk::QuadEdgeMeshConstIterator< itk::QuadEdge >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_BeginOnext(self, *args)

    def EndOnext(self, *args):
        r"""
        EndOnext(self) -> itk::QuadEdgeMeshIterator< itk::QuadEdge >
        EndOnext(self) -> itk::QuadEdgeMeshConstIterator< itk::QuadEdge >
        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_EndOnext(self, *args)

    def SetOnext(self, onext):
        r"""
        SetOnext(self, onext)

        Parameters
        ----------
        onext: itkQuadEdge *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_SetOnext(self, onext)

    def SetRot(self, rot):
        r"""
        SetRot(self, rot)

        Parameters
        ----------
        rot: itkQuadEdge *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_SetRot(self, rot)

    def Splice(self, b):
        r"""
        Splice(self, b)

        Parameters
        ----------
        b: itkQuadEdge *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_Splice(self, b)

    def IsHalfEdge(self):
        r"""IsHalfEdge(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsHalfEdge(self)

    def IsIsolated(self):
        r"""IsIsolated(self) -> bool"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsIsolated(self)

    def IsEdgeInOnextRing(self, testEdge):
        r"""
        IsEdgeInOnextRing(self, testEdge) -> bool

        Parameters
        ----------
        testEdge: itkQuadEdge *

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsEdgeInOnextRing(self, testEdge)

    def IsLnextGivenSizeCyclic(self, size):
        r"""
        IsLnextGivenSizeCyclic(self, size) -> bool

        Parameters
        ----------
        size: int const

        """
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_IsLnextGivenSizeCyclic(self, size)

    def GetOrder(self):
        r"""GetOrder(self) -> unsigned int"""
        return _itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_GetOrder(self)

# Register itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer in _itkQuadEdgeMeshLineCellPython:
_itkQuadEdgeMeshLineCellPython.itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer_swigregister(itkQuadEdgeMeshLineCellCIDQEMCTI3_AutoPointer)

